"""Controller holding and managing Vantage buttons."""

from typing import Sequence

from typing_extensions import override

from aiovantage.command_client.object_interfaces import ButtonInterface
from aiovantage.models import Button

from .base import BaseController, State


class ButtonsController(BaseController[Button], ButtonInterface):
    """Controller holding and managing Vantage buttons."""

    vantage_types = ("Button",)
    """The Vantage object types that this controller will fetch."""

    status_types = ("BTN",)
    """Which Vantage 'STATUS' types this controller handles, if any."""

    @override
    async def fetch_object_state(self, _vid: int) -> State:
        """Fetch the state properties of a dry contact."""
        return {
            # Buttons are momentary, so default to not pressed to avoid a lookup
            "pressed": False,
        }

    @override
    def parse_object_update(self, _vid: int, status: str, args: Sequence[str]) -> State:
        """Handle state changes for a button."""
        if status != "BTN":
            return None

        # STATUS BTN
        # -> S:BTN <id> <state (PRESS/RELEASE)>
        return {
            "pressed": args[0] == "PRESS",
        }
